@@ -28,6 +28,7 @@
 
 #include <libemail-engine/libemail-engine.h>
 
+#include <mail/e-mail-browser.h>
 #include <mail/e-mail-reader.h>
 #include <mail/em-folder-tree.h>
 
@@ -54,7 +55,7 @@ void em_utils_selection_get_mailbox (GtkSelectionData *data, CamelFolder *folder
 void em_utils_selection_get_message (GtkSelectionData *data, CamelFolder *folder);
 void em_utils_selection_set_uidlist (GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
 void em_utils_selection_get_uidlist (GtkSelectionData *data, EMailSession *session, CamelFolder *dest, gint move, GCancellable *cancellable, GError **error);
-void em_utils_selection_set_urilist (GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
+void em_utils_selection_set_urilist (GdkDragContext *context, GtkSelectionData *data, CamelFolder *folder, GPtrArray *uids);
 void em_utils_selection_get_urilist (GtkSelectionData *data, CamelFolder *folder);
 
 /* Return TRUE to continue, FALSE to stop further processing */
@@ -76,10 +77,19 @@ gchar *		em_utils_message_to_html	(CamelSession *session,
 						 CamelMimeMessage *msg,
 						 const gchar *credits,
 						 guint32 flags,
-						 struct _EMailPartList *parts_list,
+						 struct _EMailPartList *part_list,
 						 const gchar *prepend,
 						 const gchar *append,
 						 EMailPartValidityFlags *validity_found);
+gchar *		em_utils_message_to_html_ex	(CamelSession *session,
+						 CamelMimeMessage *message,
+						 const gchar *credits,
+						 guint32 flags,
+						 EMailPartList *part_list,
+						 const gchar *prepend,
+						 const gchar *append,
+						 EMailPartValidityFlags *validity_found,
+						 EMailPartList **out_part_list);
 
 void		em_utils_empty_trash		(GtkWidget *parent,
 						 EMailSession *session);
@@ -110,6 +120,26 @@ gboolean	em_utils_process_autoarchive_sync
 gchar *		em_utils_build_export_basename	(CamelFolder *folder,
 						 const gchar *uid,
 						 const gchar *extension);
+gchar *		em_utils_account_path_to_folder_uri
+						(CamelSession *session,
+						 const gchar *account_path); /* On This Computer/Inbox/Subfolder... */
+EMailBrowser *	em_utils_find_message_window	(EMailFormatterMode display_mode,
+						 CamelFolder *folder,
+						 const gchar *message_uid);
+gboolean	em_utils_import_pgp_key		(GtkWindow *parent,
+						 CamelSession *session,
+						 const guint8 *keydata,
+						 gsize keydata_size,
+						 GError **error);
+void		em_utils_print_part_list	(EMailPartList *part_list,
+						 EMailDisplay *mail_display,
+						 GtkPrintOperationAction print_action,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	em_utils_print_part_list_finish	(GObject *source_object,
+						 GAsyncResult *result,
+						 GError **error);
 
 G_END_DECLS
 
